@@ -19,10 +19,9 @@ package org.debian.maven.repo;
 import java.io.BufferedReader;
 import java.io.BufferedWriter;
 import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.FileReader;
-import java.io.FileWriter;
+import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.OutputStreamWriter;
 import java.io.Writer;
 import java.util.*;
 import java.util.logging.Level;
@@ -35,6 +34,7 @@ import javax.xml.stream.XMLStreamWriter;
 
 import org.debian.maven.cliargs.ArgumentsMap;
 import org.debian.maven.repo.POMInfo.DependencyType;
+import org.debian.maven.util.Readers;
 import org.debian.maven.util.Strings;
 import org.debian.maven.util.XMLWriterWrapper;
 
@@ -167,7 +167,7 @@ public class POMTransformer extends POMReader {
         });
     }
 
-    public void keepPomVersion(File pomFile) throws XMLStreamException, FileNotFoundException {
+    public void keepPomVersion(File pomFile) throws XMLStreamException, IOException {
         Dependency pom = readPom(pomFile).getThisPom();
         depRules.get(RULES).add(new DependencyRule(pom.getGroupId() + " " + pom.getArtifactId() + " " + pom.getType() + " " + pom.getVersion()));
     }
@@ -278,8 +278,8 @@ public class POMTransformer extends POMReader {
             Dependency parentDependency = null;
             String element = null;
             boolean afterText = false;
-            XMLStreamReader parser = factory.createXMLStreamReader(new BufferedReader(new FileReader(originalPom)));
-            out = new BufferedWriter(new FileWriter(targetPom));
+            XMLStreamReader parser = factory.createXMLStreamReader(new BufferedReader(Readers.read(originalPom)));
+            out = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(targetPom), "UTF-8"));
             XMLStreamWriter writer = outFactory.createXMLStreamWriter(out);
             XMLWriterWrapper writerWrapper = new XMLWriterWrapper(writer);
 
